import Reporter from '@tencent/tongxin-log-reporter';
import * as history from 'history';
import { ulid } from 'ulid';

const uuid = ulid();
const getUUID = (id: string): string => {
    try {
        const key = `__${id}__uuid`;
        const deviceId = window.localStorage.getItem(key) as string;
        if (deviceId !== null) {
            return deviceId;
        }

        window.localStorage.setItem(key, uuid);

        return uuid;
    } catch (e) {
        // 无痕模式
        return uuid;
    }
};

export const logger = new Reporter({
    id: 'tccc',
    collectDataSet: 'collect',
    reportSpeed: true,
    reportError: true,
    reportRouter: true,
    ignoreUrl: [
        /\/ccc\/debug\/seatLog/,
        /\/tcccadmin\/feedbackqueue\/queryQueueCount/,
        /\/ccc\/report\/seatConnectionState/,
        /\/ccc\/report\/seatNetworkQuality/,
        /AVQualityReportSvc/,
        /https:\/\/tpstelemetry.tencent.com/,
        /https:\/\/qcloudimg.tencent-cloud.cn/,
        /https:\/\/schedule.rtc.qcloud.com/,
        /https:\/\/schedule.rtc.qq.com/,
        /https:\/\/aegis.qq.com/,
        /https:\/\/imgcache.qq.com/,
    ],
    attributes: {
        module: 'vue3-uikit',
        uuid: getUUID('tccc'),
    },
    beforeReport(args) {
        if (process.env.NODE_ENV === 'development') return;
        if (args.type === 'history-change') {
            try {
                return {
                    to: history!.parsePath(args.to)!.pathname!.replace(/\/14\w{8}/, ''),
                    from: history!.parsePath(args.from)!.pathname!.replace(/\/14\w{8}/, ''),
                } as any;
            } catch (e) {
                console.log(e);
            }
        }

        if (args.type === 'xhr-report') {
            try {
                const res = JSON.parse(args.response);
                if (res.errorCode) {
                    return {
                        isSuccess: res.errorCode !== '-999',
                        errorCode: res.errorCode,
                        requestId: res.requestId,
                        response: undefined,
                    };
                }
            } catch (e) {
                console.log(e);
            }
        }
    },
});